Skip to main content
Version: v2.x

Hasura CLI: hasura metadata diff

(PREVIEW) Show a highlighted diff of Hasura metadata.

Synopsis​

(PREVIEW) Show changes between two different sets of Hasura metadata. By default, it shows changes between the exported metadata file and server metadata.

hasura metadata diff [file1] [file2] [flags]

Examples​

# NOTE: This command is in preview, usage and diff format may change.

# Show changes between server metadata and the exported metadata file:
hasura metadata diff

# Apply admin secret for Hasura GraphQL engine:
hasura metadata diff --admin-secret "<admin-secret>"

# Specify a diff type
hasura metadata diff --type "unified-json"
hasura metadata diff --type "json"

# Diff metadata on a different Hasura instance:
hasura metadata diff --endpoint "<endpoint>"

Options​

-h, --help          help for diff
--type string specify a type of diff [allowed values: unified-json,unified-yaml, yaml, json]

Options inherited from parent commands​

--admin-secret string            admin secret for Hasura GraphQL engine (env "HASURA_GRAPHQL_ADMIN_SECRET")
--certificate-authority string path to a cert file for the certificate authority (env "HASURA_GRAPHQL_CERTIFICATE_AUTHORITY")
--endpoint string http(s) endpoint for Hasura GraphQL engine (env "HASURA_GRAPHQL_ENDPOINT")
--envfile string .env filename to load ENV vars from (default ".env")
--insecure-skip-tls-verify skip TLS verification and disable cert checking (default: false) (env "HASURA_GRAPHQL_INSECURE_SKIP_TLS_VERIFY")
--log-level string log level (DEBUG, INFO, WARN, ERROR, FATAL) (default "INFO")
--no-color do not colorize output (default: false)
--project string directory where commands are executed (default: current dir)
--skip-update-check skip automatic update check on command execution

SEE ALSO​

  • hasura metadata - Manage Hasura GraphQL engine metadata saved in the database

Auto generated by spf13/cobra